@@ -1,8 +1,8 @@
 use thrift::Error;
 
-use iotdb::client::Client;
 use iotdb::pretty;
-use iotdb::session::Session;
+use iotdb::Client;
+use iotdb::Session;
 use std::collections::HashMap;
 
 fn main() -> Result<(), Error> {
